<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>VexRay Playground — {{ meta.title }}</title>
    <meta name="description"
        content="Interactive playground for {{ meta.title }} — tweak parameters and see results live.">

    <!-- Google Fonts -->
    <link rel="preconnect" href="https://fonts.googleapis.com">
    <link
        href="https://fonts.googleapis.com/css2?family=Inter:wght@300;400;500;600;700;800;900&family=JetBrains+Mono:wght@400;500;600&display=swap"
        rel="stylesheet">

    <!-- Plotly.js for Graphs -->
    <script src="https://cdn.plot.ly/plotly-2.35.2.min.js"></script>

    <!-- Custom Styles -->
    <link rel="stylesheet" href="{{ url_for('static', filename='style.css') }}">
</head>

<body>
    {% block content %}{% endblock %}
</body>

</html>